import { scaleOrdinal, select } from 'd3';

const colorScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal().domain(['apple', 'lemon']).range([80, 50]);

export const fruitBowl = (selection, props) => {
  const { fruits, height } = props;

  const bowl = selection
    .selectAll('rect')
    .data([null])
    .enter()
    .append('rect')
    .attr('y', 110)
    .attr('width', 920)
    .attr('height', 300)
    .attr('rx', 300 / 2);

  const groupsUpdate = selection.selectAll('g').data(fruits);
  const groupsEnter = groupsUpdate.enter().append('g');
  const groups = groupsEnter.merge(groupsUpdate);

  groups.attr(
    'transform',
    (d, i) => `translate(${i * 180 + 100},${height / 2})`
  );

  groupsUpdate.exit().remove();

  groupsEnter
    .append('circle')
    .merge(groupsUpdate.select('circle'))
    .attr('r', (d) => radiusScale(d.type))
    .attr('fill', (d) => colorScale(d.type));

  groupsEnter
    .append('text')
    .merge(groupsUpdate.select('text'))
    .text((d) => d.type)
    .attr('y', 120);
  
  groups.each(function (d) {
    const innerGroup = select(this);
    const rects = innerGroup
      .selectAll('rect')
      .data((d) => d3.range(d.num).map(() => d));

    rects
      .enter()
      .append('rect')
      .attr('height', '30px')
      .attr('stroke', 'black')
      .merge(rects)
      .attr('y', (d, i) => -40 * (i + 1))
      .attr('width', (d) => radiusScale(d.type));

    rects.exit().remove();
  });
};
